@@ -25,6 +25,8 @@
 #include "ui_managethemes.h"
 #include <QtMaemo5/QMaemo5InformationBox>
 #include <QFileDialog>
+#include <QDirIterator>
+#include <QFileInfo>
 
 namespace Ui {
     class MainWindow;
@@ -54,6 +56,7 @@ private:
     QHash<QString, QString> gtkrc;
     void readSettings();
     void writeSettings();
+    void clean();
     void SetOpacity(QString imagefile, int opacity);
     void runscript(QString command);
     QString f1;
